@@ -1,6 +1,6 @@
 
 /* 
- * Copyright 2004-2005 OpenSymphony 
+ * Copyright 2001-2009 James House 
  * 
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not 
  * use this file except in compliance with the License. You may obtain a copy 
@@ -280,6 +280,27 @@ public abstract class Trigger implements java.io.Serializable, Cloneable,
         // do nothing...
     }
 
+    /**
+     * <p>
+     * Create a <code>Trigger</code> with the given name, and default group.
+     * </p>
+     * 
+     * <p>
+     * Note that the {@link #setJobName(String)}and
+     * {@link #setJobGroup(String)}methods must be called before the <code>Trigger</code>
+     * can be placed into a {@link Scheduler}.
+     * </p>
+     * 
+     * @param group if <code>null</code>, Scheduler.DEFAULT_GROUP will be used.
+     * 
+     * @exception IllegalArgumentException
+     *              if name is null or empty, or the group is an empty string.
+     */
+    public Trigger(String name) {
+        setName(name);
+        setGroup(null);
+    }
+    
     /**
      * <p>
      * Create a <code>Trigger</code> with the given name, and group.
