@@ -1,5 +1,5 @@
 /* 
- * Copyright 2004-2005 OpenSymphony 
+ * Copyright 2001-2009 James House 
  * 
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not 
  * use this file except in compliance with the License. You may obtain a copy 
@@ -398,7 +398,7 @@ public class OracleDelegate extends StdJDBCDelegate {
                 ps.setString(2, trigger.getName());
                 ps.setString(3, trigger.getGroup());
         
-                ps.executeUpdate();
+                res = ps.executeUpdate();
             }
             
         } finally {
@@ -502,7 +502,7 @@ public class OracleDelegate extends StdJDBCDelegate {
                     ps2.setString(2, trigger.getName());
                     ps2.setString(3, trigger.getGroup());
 
-                    ps2.executeUpdate();
+                    res = ps2.executeUpdate();
                 }
             }
 
